ConnectionStateEvent class
Emitted when there's a change in the connection state.
- Inheritance
-
- Object
- PipecatEvent
- ConnectionStateEvent
Constructors
- ConnectionStateEvent({required ConnectionState state})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state ↔ ConnectionState
-
getter/setter pair
Methods
-
encode(
) → Object -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
decode(
Object result) → ConnectionStateEvent