PipecatHostApi class

Constructors

PipecatHostApi({BinaryMessenger? binaryMessenger, String messageChannelSuffix = ''})
Constructor for PipecatHostApi. The binaryMessenger named argument is available for dependency injection. If it is left null, the default BinaryMessenger will be used which routes to the host platform.

Properties

hashCode int
The hash code for this object.
no setterinherited
pigeonVar_binaryMessenger BinaryMessenger?
final
pigeonVar_messageChannelSuffix String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

disconnect() Future<void>
Acts as a dispose too
muteBotAudio({required bool isMuted}) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendClientMessage(SendClientMessageParams parameters) Future<void>
Send a custom RTVI client-message payload to the bot.
sendClientRequest(SendClientRequestParams parameters) Future<SendClientRequestResult>
Send a custom RTVI client-message request and await server-response.
sendLlmFunctionCallResult(SendLlmFunctionCallResultParams parameters) Future<void>
Send LLM function call result to the bot following RTVI message schema.
sendText(SendTextParams parameters) Future<void>
Send typed text input to the bot.
startAndConnect(StartBotParams parameters) Future<void>
Starts the session and connects to your transport
toggleCamera({required bool isEnabled}) Future<void>
Toggle your camera
toggleMicrophone({required bool isEnabled}) Future<void>
Toggle your microphone
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

pigeonChannelCodec → const MessageCodec<Object?>