SendTextParams class

Parameters for sending text input to the bot.

Constructors

SendTextParams({required String content, bool? runImmediately, bool? audioResponse})

Properties

audioResponse bool?
Whether the bot should respond with audio.
getter/setter pair
content String
Text content to send.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
runImmediately bool?
Whether the bot should run this input immediately.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

decode(Object result) SendTextParams