UserTranscriptionEvent class
Real-time transcription of user speech, including both partial and final results.
- Inheritance
-
- Object
- PipecatEvent
- UserTranscriptionEvent
Constructors
- UserTranscriptionEvent({required String text, required bool isFinal, required String timestamp, required String userId})
Properties
Methods
-
encode(
) → Object -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
decode(
Object result) → UserTranscriptionEvent