pipecat_flutter_platform_interface library
Classes
- AudioLevel
- Audio level data for visualizers. Sent at high frequency (~50-100ms intervals).
- BackendErrorEvent
- Emitted when there's a problem connecting or during the call session.
- BotConnectionEvent
- BotLLMText
- Individual tokens streamed from the LLM as they are generated.
- BotOutputEvent
- The best-effort representation of the bot's output text, including both spoken and unspoken text.
- BotReadyEvent
- BotTTSText
- The per-token text output of the text-to-speech (TTS) service (what the TTS actually says).
- ConnectionStateEvent
- Emitted when there's a change in the connection state.
- InputStatusUpdatedEvent
- LlmFunctionCallEvent
- LLM function call request from the bot.
- MetricsEvent
- PipecatEvent
- Events that the client receives on a session.
- PipecatFlutterPlatform
- Handles communication to native SDKs
- PipecatHostApi
- PipecatMetricSample
- SendClientMessageParams
- Parameters for sending a custom RTVI client-message payload.
- SendClientRequestParams
- Parameters for sending a request-style RTVI client-message payload.
- SendClientRequestResult
- Result payload returned by server-response for a client request.
- SendLlmFunctionCallResultParams
- Parameters for sending LLM function call result using RTVI standard message.
- SendTextParams
- Parameters for sending text input to the bot.
- ServerInsightEvent
- ServerMessageEvent
- SpeakingEvent
- StartBotParams
- Parameters for starting the bot and connecting
- TimelineEvent
- UserLLMText
- Aggregated user input text that is sent to the LLM.
- UserMuteEvent
- UserTranscriptionEvent
- Real-time transcription of user speech, including both partial and final results.
Constants
- pigeonMethodCodec → const StandardMethodCodec
Functions
-
localAudioLevel(
{String instanceName = ''}) → Stream< AudioLevel> -
remoteAudioLevel(
{String instanceName = ''}) → Stream< AudioLevel> -
timelineEvents(
{String instanceName = ''}) → Stream< TimelineEvent>