pipecat_flutter_platform_interface library
Classes
- AudioLevel
- Audio level data for visualizers Sent at high frequency (~50-100ms intervals)
- BackendErrorEvent
- Emitted when there's a problem connecting or during the call session.
- BotLLMText
- Individual tokens streamed from the LLM as they are generated.
- BotOutputEvent
- The best-effort representation of the bot’s output text, including both spoken and unspoken text. In addition to transcriptions of spoken text, this message type may also include text that the bot outputs but does not speak (e.g., text sent to the client for display purposes only).
- BotTTSText
- The per-token text output of the text-to-speech (TTS) service (what the TTS actually says).
- ConnectionStateEvent
- Emitted when there's a change in the connection state.
- InputStatusUpdatedEvent
- PipecatEvent
- Events that the client receives on a session
- PipecatFlutterPlatform
- Handles communication to native SDKs
- PipecatHostApi
- SendTextParams
- Parameters for sending text input to the bot.
- ServerInsightEvent
- SpeakingEvent
- StartBotParams
- Parameters for starting the bot and connecting
- UserLLMText
- Aggregated user input text that is sent to the LLM.
- UserTranscriptionEvent
- Real-time transcription of user speech, including both partial and final results.
Constants
- pigeonMethodCodec → const StandardMethodCodec
Functions
-
botOutput(
{String instanceName = ''}) → Stream< BotOutputEvent> -
connectionStateEvents(
{String instanceName = ''}) → Stream< ConnectionStateEvent> -
events(
{String instanceName = ''}) → Stream< PipecatEvent> -
inputStatusEvents(
{String instanceName = ''}) → Stream< InputStatusUpdatedEvent> -
localAudioLevel(
{String instanceName = ''}) → Stream< AudioLevel> -
remoteAudioLevel(
{String instanceName = ''}) → Stream< AudioLevel> -
speakingEvents(
{String instanceName = ''}) → Stream< SpeakingEvent> -
userTranscriptions(
{String instanceName = ''}) → Stream< UserTranscriptionEvent>