PipecatFlutterPlatform class abstract
Handles communication to native SDKs
- Inheritance
-
- Object
- PlatformInterface
- PipecatFlutterPlatform
Constructors
- PipecatFlutterPlatform()
- Handles communication to native SDKs
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
localAudioLevelStream
→ Stream<
AudioLevel> -
Local user's microphone level (0.0 - 1.0)
no setter
-
remoteAudioLevelStream
→ Stream<
AudioLevel> -
Remote participant's (bot) audio level (0.0 - 1.0)
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
timelineEventStream
→ Stream<
TimelineEvent> -
Canonical ordered timeline stream from native runtime.
no setter
Methods
-
disconnect(
) → Future< void> - Disconnects to the room
-
muteBotMicrophone(
{required bool isMuted}) → Future< void> - Unsubscribes to the microphone stream of the bot
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sendClientMessage(
{required String msgType, required String dataJson}) → Future< void> - Send a custom RTVI client-message payload.
-
sendClientRequest(
{required String msgType, required String dataJson}) → Future< SendClientRequestResult> - Send a custom RTVI client-message request and await server-response.
-
sendLlmFunctionCallResult(
{required String functionName, required String toolCallId, required String argumentsJson, required String resultJson}) → Future< void> - Send an LLM function call result directly using RTVI standard message.
-
sendText(
{required String content, bool? runImmediately, bool? audioResponse}) → Future< void> - Send text input directly to the bot.
-
startAndConnect(
StartBotParams params) → Future< void> - Initializes the client, and starts to connect to the room
-
toggleCamera(
{required bool isEnabled}) → Future< void> - Toggles your camera on or off
-
toggleMicrophone(
{required bool isEnabled}) → Future< void> - Toggles your microphone on or off
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ PipecatFlutterPlatform
-
Get the instance of this singleton
getter/setter pair